.. :changelog:

Release History
===============

0.1.1b3 (2017-02-17)
++++++++++++++++++++

* Add backup and restore commands
* Add App Service SSL commands
* Fixes bug with adding hostname to web app
* Prompts for yes / no use the -y option rather than --force
* Show commands return empty string with exit code 0 for 404 responses


0.1.1b2 (2017-01-30)
++++++++++++++++++++

* Add user path expansion to file type parameters.
* Add confirmation prompt to 'appservice plan delete'.
* Support Python 3.6.

0.1.1b1 (2017-01-17)
+++++++++++++++++++++

* Add webapp start

0.1.0b11 (2016-12-12)
+++++++++++++++++++++

* Preview release.
